@@ -10,6 +10,7 @@ from prompt_toolkit.formatted_text import FormattedText
 from prompt_toolkit import print_formatted_text
 import re
 import subprocess
+from .extract import url_to_text
 
 openai.api_key = os.getenv("OPENAI_API_KEY")
 
@@ -31,13 +32,21 @@ chat_ctx = ChatContext(min_response_tokens=800,  # leave room for at least this
                        temperature=0.1,
                        base_system_msg_text=BASE_PROMPT)
     
-
+def print_help():
+    print("Available commands:")
+    print("/file <path> - Load a file into the context")
+    print("/cd <path> - Change the current working directory")
+    print("/url <url> - Load the content of a URL into the context")
+    print("/status - Show the status of the OPENAI_API_KEY and the model being used")
+    print("/help - Display this help message")
+    
 
 def repl():
     path_completer = PathCompleter(only_directories=False, expanduser=True)
     custom_completer = NestedCompleter.from_nested_dict({
         '/file': path_completer,
-        '/cd': path_completer
+        '/cd': path_completer,
+        '/url': WordCompleter(['http://', 'https://']),
     })
 
     # Create custom key bindings
@@ -60,7 +69,10 @@ def repl():
     print_formatted_text(FormattedText([("fg:violet", "Pair AI Programming REPL  ")]))
     while True:
         # Read user input with custom autocompletion
-        user_input = session.prompt("Enter your code, questions, or /file <path>, or /cd <path>:  \n")
+        user_input = session.prompt("Enter your code, questions, or /file <path>,  or /help to see all commands:  \n")
+
+        if user_input.strip() == '':
+            continue
 
         # Check for the special /file command
         if user_input.startswith('/file'):
@@ -76,6 +88,12 @@ def repl():
             except FileNotFoundError:
                 print(f"File not found: {file_path}")
                 continue
+            except IsADirectoryError:
+                print(f"Path is a directory, not a file: {file_path}")
+                continue
+            except Exception as e:
+                print(f"Unexpected error: {e}")
+                continue
         # Check for the special /cd command
         elif user_input.startswith('/cd'):
             dir_path = user_input[4:].strip()
@@ -88,8 +106,39 @@ def repl():
             except NotADirectoryError:
                 print(f"Not a directory: {dir_path}")
                 continue
-            continue  # Add this line to skip processing the /cd command as a user input for assistance
-            
+            continue  # Add this line to skip processing the /cd command as a user input for assistance         
+        # Check for the special /url command
+        elif user_input.startswith('/url'):
+             url = user_input[5:].strip()
+             try:
+                 content, title, language = url_to_text(url)
+                 user_input = f'{url}:\n{content}\n'
+                 msg = UserMessage(text=user_input)
+                 chat_ctx.add_message(msg)
+                 print(content)
+                 print(f"Loaded {msg.tokens} tokens from {url} into context  ")
+                 continue
+             except Exception as e:
+                 print(f"Error fetching URL: {e}")
+                 continue
+        # Check for the special /status command
+        elif user_input.startswith('/status'):
+            api_key_status = "set" if openai.api_key else "not set"
+            model_name = chat_ctx.model
+            try:
+                openai.Model.retrieve(model_name)
+                model_status = "available"
+            except Exception as e:
+                model_status = f"unavailable ({e})"
+
+            print(f"OPENAI_API_KEY: {api_key_status}")
+            print(f"Model: {model_name} ({model_status})")
+            continue  # Add this line to skip processing the /status command as a user input for assistance
+        # Check for the special /help command
+        elif user_input.startswith('/help'):
+            print_help()
+            continue  # Add this line to skip processing the /help command as a user input for assistance            
+        
         print("~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~  ")
         cr = chat_ctx.user_message(user_input, stream=True)
         print_formatted_text(FormattedText([("fg:olive", f"({cr.input_tokens} + {cr.response_tokens} tokens = ${cr.price:.4f})  ")]))
